import React, { useState } from "react";
import { ProCard, ProTable, PageContainer } from "@ant-design/pro-components";
import { Card, Col, Row, Button, Input, Breadcrumb, Empty } from "antd";
import { history, useRequest } from "umi";
import { AppstoreOutlined, MenuOutlined } from "@ant-design/icons";
import { FlowchartMindMapList } from "@/api/systemDesigner";
import { GraphType } from "@/enum";

import defaultFlowImg from "@/assets/image/flow.png";
import defaultMindImg from "@/assets/image/mindmap.png";
export default function Recently() {
  const [display, setDisplay] = useState("card");
  const [dataSource, setDataSource] = useState<any[]>([]);
  const handleToEdit = (record: any) => {
    if(record.type === GraphType.mindmap) {
      history.push(`/mindmap/${record.id}`);
    } else {
      history.push(`/flow/${record.id}`);
    }
  };

  const { loading, run } = useRequest(FlowchartMindMapList, {
    onSuccess: (res) => {
      setDataSource(res?.result?.model || []);
    },
  });

  return (
    <>
      <PageContainer
        extra={[
          <Button
            key="1"
            onClick={() => {
              setDisplay(display === "card" ? "list" : "card");
            }}
            icon={<i className="iconfont icon-shaixuan" />}
          />,
          <Button
            key="2"
            onClick={() => {
              setDisplay(display === "card" ? "list" : "card");
            }}
            icon={display === "card" ? <MenuOutlined /> : <AppstoreOutlined />}
          />,
        ]}
        title={
          <Input
            placeholder="搜索文件/文件夹"
            prefix={<i className="iconfont icon-chazhao" />}
          />
        }
        footer={[]}
      >
        <ProCard
          style={{
            height: "calc(100vh - 140px)",
            minHeight: 800,
            overflow: "auto",
          }}
        >
          <Breadcrumb
            items={[
              {
                title: "最近",
              },
            ]}
          ></Breadcrumb>
          {display === "card" ? (
            <>
              <div className="text-12px color-#999 my-8px">文件</div>
              <Row gutter={[8, 16]}>
                {dataSource.map((item, index) => {
                  return (
                    <Col
                      xs={12}
                      sm={8}
                      md={6}
                      lg={6}
                      xl={6}
                      xxl={6}
                      key={index}
                    >
                      <Card
                        hoverable
                        bordered
                        cover={
                          <img
                            style={{ height: 200, objectFit: "cover" }}
                            alt="example"
                            src={item?.coverImage || (item.type === GraphType.mindmap ? defaultMindImg : defaultFlowImg)}
                          />
                        }
                        onClick={() => handleToEdit(item)}
                      >
                        <Card.Meta
                          title={
                            <span>
                              {item.type === GraphType.mindmap ? (
                                <i
                                  className={`iconfont icon-siweidaotu_huaban1 color-#3bc9c1 mr-8px`}
                                />
                              ) : (
                                <i
                                  className={`iconfont icon-liuchengtu color-#067bef mr-8px`}
                                />
                              )}
                              {item.name}
                            </span>
                          }
                          description={`更新于: ${item.updatedTime}`}
                        />
                      </Card>
                    </Col>
                  );
                })}
              </Row>
              {
                dataSource.length == 0 ?
                <Empty description="暂无数据" />
                : null
              }
            </>
          ) : (
            <ProTable
              columns={[
                {
                  title: "名称",
                  dataIndex: "name",
                },
                {
                  title: "类型",
                  dataIndex: "type",
                },
                {
                  title: "修改时间",
                  dataIndex: "updatedTime",
                },
              ]}
              dataSource={dataSource}
              rowKey={"id"}
              search={false}
            />
          )}
        </ProCard>
      </PageContainer>
    </>
  );
}
